@@ -21,13 +21,15 @@ import json
 import yaml
 
 
-def configure_parser(parser, _):
+def configure_parser(parser, version):
     sub = parser.add_subparsers(dest="sub_sub_command", help="Sub commands")
     sub.required = True
 
     # "add"
     aliases_add = sub.add_parser("add", help="add an alias")
     aliases_add.add_argument("alias", help="alias name")
+    if version >= (2019, 5):
+        aliases_add.add_argument("device_type", help="device-type")
 
     # "delete"
     aliases_del = sub.add_parser("delete", help="delete an alias")
@@ -79,17 +81,20 @@ def help_string():
     return "manage device-type aliases"
 
 
-def handle_add(proxy, options):
-    proxy.scheduler.aliases.add(options.alias)
+def handle_add(proxy, options, config):
+    if config["version"] >= (2019, 5):
+        proxy.scheduler.aliases.add(options.alias, options.device_type)
+    else:
+        proxy.scheduler.aliases.add(options.alias)
     return 0
 
 
-def handle_delete(proxy, options):
+def handle_delete(proxy, options, _):
     proxy.scheduler.aliases.delete(options.alias)
     return 0
 
 
-def handle_list(proxy, options):
+def handle_list(proxy, options, _):
     aliases = proxy.scheduler.aliases.list()
     if options.output_format == "json":
         print(json.dumps(aliases))
@@ -102,25 +107,29 @@ def handle_list(proxy, options):
     return 0
 
 
-def handle_show(proxy, options):
+def handle_show(proxy, options, config):
     alias = proxy.scheduler.aliases.show(options.alias)
     if options.output_format == "json":
         print(json.dumps(alias))
     elif options.output_format == "yaml":
         print(yaml.dump(alias).rstrip("\n"))
     else:
-        print("name        : %s" % alias["name"])
-        print("device-types:")
-        for dt in alias["device_types"]:
-            print("* %s" % dt)
+        if config["version"] >= (2019, 5):
+            print("name       : %s" % alias["name"])
+            print("device-type: %s" % alias["device_type"])
+        else:
+            print("name        : %s" % alias["name"])
+            print("device-types:")
+            for dt in alias["device_types"]:
+                print("* %s" % dt)
     return 0
 
 
-def handle(proxy, options, _):
+def handle(proxy, options, config):
     handlers = {
         "add": handle_add,
         "delete": handle_delete,
         "list": handle_list,
         "show": handle_show,
     }
-    return handlers[options.sub_sub_command](proxy, options)
+    return handlers[options.sub_sub_command](proxy, options, config)
