@@ -22,6 +22,8 @@ import json
 import time
 import yaml
 
+from lavacli.utils import loader
+
 
 def configure_parser(parser, version):
     sub = parser.add_subparsers(dest="sub_sub_command", help="Sub commands")
@@ -297,7 +299,9 @@ def handle_dict(proxy, options, _):
             return 0
 
         if options.render:
-            value = yaml.safe_load(str(config))
+            value = yaml.load(  # nosec - loader() returns a safe loader
+                str(config), Loader=loader()
+            )
             return _lookups(value, options.field.split("."))
         else:
             # Extract some variables
