@@ -28,8 +28,7 @@ from urllib.parse import urlparse
 import xmlrpc.client
 import yaml
 
-from lavacli.utils import loader
-from lavacli.utils import print_u
+from lavacli.utils import loader, print_u, exc2str
 
 
 def configure_parser(parser, version):
@@ -38,7 +37,7 @@ def configure_parser(parser, version):
 
     # "cancel"
     jobs_cancel = sub.add_parser("cancel", help="cancel a job")
-    jobs_cancel.add_argument("job_id", help="job id")
+    jobs_cancel.add_argument("job_id", nargs="+", help="job id")
 
     if version >= (2018, 4):
         # "config"
@@ -298,6 +297,12 @@ def configure_parser(parser, version):
             type=int,
             help="polling interval in seconds [default=5s]",
         )
+        jobs_wait.add_argument(
+            "--timeout",
+            default=0,
+            type=int,
+            help="Maximum time to wait in seconds, 0 to disable [default=0s]",
+        )
 
 
 def help_string():
@@ -305,7 +310,11 @@ def help_string():
 
 
 def handle_cancel(proxy, options, _):
-    proxy.scheduler.jobs.cancel(options.job_id)
+    for job_id in options.job_id:
+        try:
+            proxy.scheduler.jobs.cancel(job_id)
+        except xmlrpc.client.Error as exc:
+            print("Unable to cancel job %s: %s" % (job_id, exc2str(exc)))
     return 0
 
 
@@ -502,10 +511,10 @@ def print_logs(logs, raw, filters):
 def _download_logs(proxy, version, job_id, start, end):
     if version >= (2018, 6):
         (finished, data) = proxy.scheduler.jobs.logs(job_id, start, end)
-        logs = yaml.load(str(data), Loader=loader())
+        logs = yaml.load(str(data), Loader=loader(False))
     else:
         (finished, data) = proxy.scheduler.jobs.logs(job_id, start)
-        logs = yaml.load(str(data), Loader=loader())
+        logs = yaml.load(str(data), Loader=loader(False))
         if end is not None and len(logs) >= end - start:
             if end < start:
                 end = start
@@ -718,7 +727,7 @@ def handle_submit(proxy, options, _):
             else:
                 print(prefix + str(job_id))
         except xmlrpc.client.Error as exc:
-            print("Unable to submit %s" % definition.name)
+            print("Unable to submit %s: %s" % (definition.name, exc2str(exc)))
 
     return 0
 
@@ -727,7 +736,7 @@ def handle_validate(proxy, options, _):
     ret = proxy.scheduler.jobs.validate(options.definition.read(), options.strict)
     if not ret:
         return 0
-    print("key: %s" % ".".join(ret["path"]))
+    print("key: %s" % ret["path"])
     print("msg: %s" % ret["msg"])
     return 1
 
@@ -735,6 +744,7 @@ def handle_validate(proxy, options, _):
 def handle_wait(proxy, options, _):
     job = proxy.scheduler.jobs.show(options.job_id)
     old_state = ""
+    time_elapsed = 0
     while job["state"] != "Finished":
         if old_state != job["state"]:
             if old_state:
@@ -746,6 +756,11 @@ def handle_wait(proxy, options, _):
         old_state = job["state"]
         time.sleep(options.polling)
         job = proxy.scheduler.jobs.show(options.job_id)
+        if options.timeout > 0:
+            time_elapsed = time_elapsed + options.polling
+            if time_elapsed > options.timeout:
+                print("timeout!")
+                return 1
     if old_state != job["state"] and old_state:
         sys.stdout.write("\n")
     return 0
