@@ -21,6 +21,8 @@ import json
 import sys
 import yaml
 
+from lavacli.utils import loader
+
 
 def configure_parser(parser, _):
     parser.add_argument("job_id", help="job id")
@@ -61,7 +63,7 @@ def handle(proxy, options, _):
     else:
         data = proxy.results.get_testjob_results_yaml(options.job_id)
 
-    results = yaml.safe_load(data)
+    results = yaml.load(data, Loader=loader())  # nosec - loader() returns a safe loader
 
     if options.output_format == "json":
         print(json.dumps(results))
