@@ -55,6 +55,22 @@ def configure_parser(parser, version):
         "config", type=argparse.FileType("r"), help="configuration file"
     )
 
+    if version >= (2019, 6):
+        # "env"
+        workers_env = sub.add_parser("env", help="worker environment")
+        env_sub = workers_env.add_subparsers(
+            dest="sub_sub_sub_command", help="Sub commands"
+        )
+        env_sub.required = True
+        env_get = env_sub.add_parser("get", help="get the worker environment")
+        env_get.add_argument("hostname", type=str, help="worker hostname")
+
+        env_set = env_sub.add_parser("set", help="set the worker environment")
+        env_set.add_argument("hostname", type=str, help="worker hostname")
+        env_set.add_argument(
+            "env", type=argparse.FileType("r"), help="environment file"
+        )
+
     # "list"
     workers_list = sub.add_parser("list", help="list workers")
     out_format = workers_list.add_mutually_exclusive_group()
@@ -167,6 +183,19 @@ def handle_config(proxy, options, _):
     return 0
 
 
+def handle_env(proxy, options, _):
+    if options.sub_sub_sub_command == "get":
+        env = proxy.scheduler.workers.get_env(options.hostname)
+        print(str(env).rstrip("\n"))
+    else:
+        env = options.env.read()
+        ret = proxy.scheduler.workers.set_env(options.hostname, env)
+        if not ret:
+            print("Unable to store worker environment")
+            return 1
+    return 0
+
+
 def handle_list(proxy, options, _):
     workers = proxy.scheduler.workers.list()
     if options.output_format == "json":
@@ -249,6 +278,7 @@ def handle(proxy, options, config):
     handlers = {
         "add": handle_add,
         "config": handle_config,
+        "env": handle_env,
         "list": handle_list,
         "maintenance": handle_maintenance,
         "show": handle_show,
